Learn R Programming

earth (version 1.0-6)

update.earth: Update an 'earth' model

Description

Update an earth model.

Usage

## S3 method for class 'earth':
update(object = stop("no 'object' arg"),
       formula. = NULL, ..., evaluate = TRUE)

Arguments

object
formula.
...
These arguments are the same as earth. The formula. argument is treated like earth's formula argument.
evaluate
If TRUE (default) evaluate the new call else return the call.

Value

  • The value is the same as that returned by earth. If object is the only parameter then no changes are made --- the returned value will be the same as the original object.

See Also

earth

Examples

Run this code
data(ozone1)
(a <- earth(O3 ~ ., data = ozone1, degree = 2))

# yields:
#    Selected 11 of 21 terms, and 8 of 9 predictors
#    Number of terms at each degree of interaction: 1 5 5
#    GCV: 13.43422     RSS: 3762.234     GRSq: 0.7913151     RSq: 0.8218252

update(a, formula = O3 ~ . - temp) # requires forward pass and pruning

# yields:
#    Selected 15 of 21 terms, and 8 of 8 predictors
#    Number of terms at each degree of interaction: 1 5 9
#    GCV: 13.14588     RSS: 3443.265     GRSq: 0.7957941     RSq: 0.8369311

update(a, nprune = 8)              # requires only pruning

# yields:
#    Selected 8 of 21 terms, and 6 of 9 predictors
#    Number of terms at each degree of interaction: 1 5 2
#    GCV: 15.07944     RSS: 4433.915     GRSq: 0.7657586     RSq: 0.7900152

Run the code above in your browser using DataLab