earth objects.## S3 method for class 'earth':
summary(object = stop("no 'object' arg"),
details = FALSE, style = c("h", "pmax", "max", "C", "bf"),
decomp = "anova", digits = getOption("digits"), fixed.point=TRUE,
newdata = NULL, ...)## S3 method for class 'summary.earth':
print(x = stop("no 'x' arg"),
details = x$details,
decomp = x$decomp, digits = x$digits, fixed.point = x$fixed.point,
newdata = x$newdata, ...)
earth object.
This is the only required argument for summary.earth.summary.earth object.
This is the only required argument for print.summary.earth."h" (default) more compact
"pmax" for those who prefer it and for compatibility with old versions of earth
"max" is the same as "pmax" but prints max rather than "anova".
Use "none" to order the terms as created by the forward.pass.
See format.earth for a full description.summary.earth, the default is getOption("digits").
For print.summary.earth, the default is the $digits component of object.TRUE which prints like this
(making it easier to compare coefficients):(Intercept) 15.029
h(temp-58) 0.313
h(234-ibt) -0.046
... whereas fixeNULL.
Else print R-Squared for the new data, and
if a variance model is present print the interval coverage table for the new data.
In the current implementation, newdata is allowed only if
earth was called wformat.earth.earth
but with the following extra components.format.earth.
For multiple response models, a vector of strings.print.summary.earth.earth,
evimp,
format.earthearth.mod <- earth(Volume~ ., data = trees)
summary(earth.mod, digits = 2)Run the code above in your browser using DataLab